Crate bevy_nested_tooltips

Crate bevy_nested_tooltips 

Modules

events
The events that are intended to be read by the user to react to are stored here.
highlight
Highlighting logic and components are stored here. What highlighting actually does is up to the user.
layout
Components you can query or observer in order to change appearance of the tooltips, can be used in queries when obeserving the crate::TooltipSpawned event.
prelude
An easy way to import commonly used types
term
Terms is how tooltips find out what to display given a word to link
text_observer
TextSpan’s do not currently support observers so this file is here to read hovers on text and to narrow it down to the actual textspan.

Structs

NestedTooltipPlugin
This plugin adds systems and resources that makes the logic work
Tooltip
Indicates this entity is a tooltip and stores what spawned it The entity that spawned it is blocked from spawning another tooltip until this one is finished to prevent tooltip jumping around
TooltipConfiguration
Resource that configures the behaviour of tooltips
TooltipLinkTimer
Timer added on creating a Tooltip, if the user does not mouseover the tooltip in that time then it will be despawned
TooltipMap
The data of your tooltips. When a TooltipTermLink is activated the string inside of it will be used as key for the hashmap and its result will populate the tooltip
TooltipReference
Default node for the Tooltip node use this to layout your tooltips without accidentally moving it’s position This resource is initialised on adding plugin
TooltipSpawned
This is sent when a Tooltip is spawned
TooltipWaitForHover
If the user hasn’t hovered on the tooltip in the specified time despawn it time is configured in TooltipConfiguration
TooltipsData
What is to be included in the Tooltip
TooltipsNested
Tooltip that spawned nested from this one
TooltipsNestedOf
This Tooltip is nested under the entities Tooltip

Enums

ActivationMethod
How a tooltip is triggered by default this is done via hovering Hovering can be further customised
TooltipsContent
This makes up a part of the tooltips text content. Each variant outputs text but with different behaviours See each variants documenation for details