Module layout

Module layout 

Components you can query or observer in order to change appearance of the tooltips, can be used in queries when obeserving the crate::TooltipSpawned event.

Structs

TooltipStringText
Marker for the crate::Tooltip texts that is not interactable.
TooltipTextNode
Marker for the crate::Tooltip info node, that is the node that holds all non title text.
TooltipTitleNode
Marker for the crate::Tooltip title node.
TooltipTitleText
Marker for the crate::Tooltip title text this will be place in TooltipTitleNode.