pub struct TooltipConfiguration {
pub activation_method: ActivationMethod,
pub interaction_wait_for_time: Duration,
pub starting_z_index: i32,
}Expand description
Resource that configures the behaviour of tooltips.
Fields
activation_method: ActivationMethodSee the ActivationMethod variants.
interaction_wait_for_time: DurationMaximum amount of time the ToolTip will remain around without user interaction.
starting_z_index: i32The starting z_index this will be incremented for each recursive tooltip increase this if tooltips are not on top and you want to fix that.