Components you can query or observer in order to change appearance
of the tooltips, can be used in queries when obeserving the crate::TooltipSpawned event.
Indicates this entity is a tooltip and stores what spawned it
The entity that spawned it is blocked from spawning another tooltip
until this one is finished to prevent tooltip jumping around
The data of your tooltips.
When a TooltipTermLink is activated the string inside of it will be used as key
for the hashmap and its result will populate the tooltip
Default node for the Tooltip node use this to layout your tooltips without
accidentally moving it’s position
This resource is initialised on adding plugin