Components you can query or observer in order to change appearance
of the tooltips, can be used in queries when obeserving the crate::TooltipSpawned event.
Structs
- Tooltip
String Text - Marker for the
crate::Tooltiptexts that is not interactable. - Tooltip
Text Node - Marker for the
crate::Tooltipinfo node, that is the node that holds all non title text. - Tooltip
Title Node - Marker for the
crate::Tooltiptitle node. - Tooltip
Title Text - Marker for the
crate::Tooltiptitle text this will be place inTooltipTitleNode.