The structs that are intended for the user too trigger or react too.
Structs
- Spawn
Arbitrary Tooltip - Spawn a
Tooltipwith content done at runtime. The motivating case is for sliders, in order to present a value. - Spawn
Tooltip - Manually spawn a
Tooltip, useful for icons users may click. Not currently supported for doing this in an existing tooltip. - Tooltip
Highlighting - Marker to indicate this node is currently being highlighted by this tooltip When this component is added user should apply styling so it’s obvious to the player what is being highlighted.
- Tooltip
Locked - Marker to indicate that this
Tooltipshould not be despawned. When this component is added user should apply styling so it’s obvious to the player that the tooltip will not be despawned by timeout or pointer leaving.